@@ -2,7 +2,8 @@ import re
 import importlib
 import os
 import sys
-import pytov.curly_braces as curly_braces
+#import pytov.curly_braces as curly_braces
+import curly_braces
 import traceback
 
 class Main:
@@ -205,7 +206,10 @@ class Main:
         except:
             #print(e)
             excep = traceback.format_exc()
-            lineNum = int(excep.split("\n")[3][excep.split("\n")[3].find("line") + 5:]) - 3
+            print(excep)
+            excepLine = excep.split("\n")[3][excep.split("\n")[3].find("line") + 5:]
+            print(excepLine)
+            lineNum = int(excepLine) - 3
             withoutThisFile = excep.split("\n")[0] + "\n" + "\n" + excep.split("\n")[3][:excep.split("\n")[3].find("line") + 5] + str(lineNum) + "\n" + "\n".join(excep.split("\n")[4:])
             print("\n" + withoutThisFile.replace('"<string>"', self.filePath))
         
